/*
 * WScout - Lightweight PCAP visualizer.
 * Copyright (C) 2007  Universite Pierre et Marie Curie - Paris 6
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301  USA
 *
 * Author: Thomas Claveirole <thomas.claveirole@lip6.fr>
 */

#ifndef WSCOUT_GUI_FILTER_DIALOG_HXX_
# define WSCOUT_GUI_FILTER_DIALOG_HXX_

# include "wscout_gui_filter_dialog.hh"

namespace wscout
{

  namespace gui
  {

    inline
    QString
    FilterDialog::inputFileName() const
    {
      return in_file_name_;
    }

    inline
    void
    FilterDialog::setInputFileName(const QString& n)
    {
      in_file_name_ = n;
    }

    inline
    QString
    FilterDialog::outputFileName() const
    {
      return out_file_name_.text();
    }

    inline
    void
    FilterDialog::setOutputFileName(const QString& n)
    {
      out_file_name_.setText(n);
    }

    inline
    void
    FilterDialog::setDefaultFilter(const QString& f)
    {
      default_filter_ = f;
    }

    inline
    void
    FilterDialog::setDefaultCommand(const QString& c)
    {
      default_command_ = c;
    }

    inline
    std::string
    FilterDialog::commandLine() const
    {
      return
	command_.text()
	.arg(in_file_name_)
	.arg(out_file_name_.text())
	.arg(filter_.text()).toStdString();
    }

    inline
    QString
    FilterDialog::prettyCommandLine() const
    {
      return tr("<p><b>Command line</b></p>"
		"<p><code>") + commandLine().c_str() + tr("</code></p>");
    }

    inline
    QString
    FilterDialog::prettyProcessOutput()
    {
      return
	tr("<p><b>Process output</b></p>"
	   "<p><code>") + process_.readAll() + tr("</code></p>");
    }

  } // End of namespace gui.

} // End of namespace wscout.

#endif // ! WSCOUT_GUI_FILTER_DIALOG_HXX_
