/*
 * WScout - Lightweight PCAP visualizer.
 * Copyright (C) 2007, 2008  Universite Pierre et Marie Curie - Paris 6
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301  USA
 *
 * Author: Thomas Claveirole <thomas.claveirole@lip6.fr>
 */

#ifndef WSCOUT_GUI_HEX_DUMP_DOCK_HH_
# define WSCOUT_GUI_HEX_DUMP_DOCK_HH_

# include <QtGui/QDockWidget>
# include <QtGui/QScrollArea>
# include <QtGui/QTextEdit>

namespace wscout
{

  namespace gui
  {

    /// Hexadecimal dumper dock widget.  Display hexadecimal content.
    class HexDumpDock : public QDockWidget
    {
      Q_OBJECT

    public:
      HexDumpDock(QWidget* parent = 0);
      HexDumpDock(const HexDumpDock&);

      void	setup(const void* data, size_t len);

    private slots:
      void	hexUpdateClipboard();
      void	asciiUpdateClipboard();

    private:
      void		init();
      void		initTextEdit(QTextEdit& te, unsigned minWidth);
      static QString	filterBlanksOut(const QString& str);

      enum
	{
	  lwidth = 16,		// Line width.
	  bwidth = 4,		// Block width.
	  addr_len = 4		// Address length, in bytes.
	};

      static const std::string	title;
      static const std::string	bigsep;
      static const std::string	smallsep;

      QWidget		dockWidget_;
      QTextEdit		addresses_;
      QTextEdit		hexData_;
      QTextEdit		asciiData_;
    };

  } // End of namespace gui.

} // End of namespace wscout.

# include "wscout_gui_hex_dump_dock.hxx"

#endif // ! WSCOUT_GUI_HEX_DUMP_DOCK_HH_
