/*
 * WScout - Lightweight PCAP visualizer.
 * Copyright (C) 2007  Universite Pierre et Marie Curie - Paris 6
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301  USA
 *
 * Author: Thomas Claveirole <thomas.claveirole@lip6.fr>
 */

#include "wscout_gui_ieee802_11_header.hh"

namespace wscout
{

  namespace gui
  {

    IEEE80211Header::IEEE80211Header(QWidget* parent):
      HeaderBase<IEEE80211Header, protocol::IEEE802_11> (parent)
    {
      setUpdatesEnabled(false);

      setForegroundRole(QPalette::WindowText);
      setBackgroundRole(QPalette::Window);
      setAutoFillBackground(true);

      const QFont	fFixed ("fixed");
      QBoxLayout* const	l = layout();

      {
	QFont bold;
	bold.setBold(true);

	desc.setFont(bold);
	desc.setMinimumWidth(desc.fontMetrics().width('x') * max_desc_len);
	l->addWidget(&desc);
      }

      duration.setMinimumWidth(duration.fontMetrics().width('x') *
			       max_duration_len);
      l->addWidget(&duration);
      l->addSpacing(default_spacing);

      flags.setFont(fFixed);
      l->addWidget(&flags);
      l->addSpacing(default_spacing);

      l->addWidget(&seq_ctl);
      l->addSpacing(before_addresses_spacing);
      l->addStretch();

      {
	for (size_t i = 0; i < sizeof (addr) / sizeof (*addr); ++i)
	  {
	    if (i)
	      {
		addr_sep[i - 1].setFrameStyle(QFrame::VLine | QFrame::Plain);
		l->addWidget(addr_sep + i - 1);
	      }
	    addr[i].setFont(fFixed);
	    l->addWidget(addr + i);
	  }
      }

      setUpdatesEnabled(true);
    }

    IEEE80211Header::next_header
    IEEE80211Header::setup(const void*			header,
			   size_t			caplen,
			   const Trace&			,
			   const pcapxx::frame_descriptor&)
    {
      wifi::frame::dissector<ieee80211_hooks>	d (ieee80211_hooks (*this));

      next = next_header (protocol::UNKNOWN, 0);
      setUpdatesEnabled(false);
      d(header, caplen);
      setUpdatesEnabled(true);
      return next;
    }

    const QColor IEEE80211Header::ieee80211_hooks::black ("black");
    const QColor IEEE80211Header::ieee80211_hooks::lightblue ("lightblue");
    const QColor IEEE80211Header::ieee80211_hooks::lightgreen ("lightgreen");
    const QColor IEEE80211Header::ieee80211_hooks::red ("red");
    const QColor IEEE80211Header::ieee80211_hooks::white ("white");
    const QColor IEEE80211Header::ieee80211_hooks::yellow ("yellow");

  } // End of namespace gui.

} // End of namespace wscout.
