/*
 * WScout - Lightweight PCAP visualizer.
 * Copyright (C) 2007  Universite Pierre et Marie Curie - Paris 6
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301  USA
 *
 * Author: Thomas Claveirole <thomas.claveirole@lip6.fr>
 */

#include <QtCore/QProcess>
#include <QtCore/QDir>

#include <boost/foreach.hpp>

#include "wscout_config.hh"
#include "wscout_gui_pixmap.hh"

namespace wscout
{

  namespace gui
  {

    const QString	pixmap_search_path_prefix = "pixmaps";

    void	pixmapInit()
    {
      const QStringList	env = QProcess::systemEnvironment();

      BOOST_FOREACH(const QString& s, env)
	{
	  const int e = s.indexOf('=');
	  if (e < 1)
	    continue;

	  const QString	name = s.left(e);
	  const QString	value = s.right(s.size() - e - 1);

	  if (name == WSCOUT_PIXMAP_PATH_ENVVAR_NAME)
	    {
	      QDir::setSearchPaths(pixmap_search_path_prefix,
				   value.split(':', QString::SkipEmptyParts));
	      break;
	    }
	}
      QDir::addSearchPath(pixmap_search_path_prefix,
			  WSCOUT_TOP_BUILDDIR "/pixmaps");
      QDir::addSearchPath(pixmap_search_path_prefix,
			  WSCOUT_TOP_SRCDIR "/pixmaps");
      QDir::addSearchPath(pixmap_search_path_prefix, WSCOUT_PIXMAP_DIR);
      QDir::addSearchPath(pixmap_search_path_prefix, ":/pixmaps");
    }

  } // End of namespace gui.

} // End of namespace wscout.
