/*
 * WScout - Lightweight PCAP visualizer.
 * Copyright (C) 2007  Universite Pierre et Marie Curie - Paris 6
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301  USA
 *
 * Author: Thomas Claveirole <thomas.claveirole@lip6.fr>
 */

extern "C"
{
# include <inttypes.h>
}

#include <boost/format.hpp>
#include <boost/lexical_cast.hpp>

#include <wipal/phy/prism_header.hh>

#include "wscout_gui_prism_header.hh"

namespace wscout
{

  namespace gui
  {

    PrismHeader::next_header
    PrismHeader::setup(const void*			h,
		       size_t				caplen,
		       const Trace&			trace,
		       const pcapxx::frame_descriptor&	fd)
    {
      if (caplen < sizeof (prism::header))
	{
	  rate.hide();
	  channel.hide();
	  signal.hide();
	  time.hide();
	  return next_header (protocol::NONE, 0);
	}

      const prism::header* const prism = static_cast<const prism::header*> (h);
      const bool		 swapped = (fd.pcap_header()->swapped xor
					    trace.swapContent());
      const std::string		 timestr =
	boost::lexical_cast<std::string> (boost::format ("%010u:%010u")
					  % prism->hosttime.get(swapped)
					  % prism->mactime.get(swapped));

      setUpdatesEnabled(false);
      time.setText(timestr.c_str());
      rate.setText(tr("%1 Mb/s").arg(prism->rate.get(swapped) / 2.));
      channel.setText(tr("channel %1").arg(prism->channel.get(swapped)));
      signal.setText(tr("rssi/signal/noise: %1 / %2 / %3")
		     .arg(prism->rssi.get(swapped))
		     .arg(prism->signal.get(swapped))
		     .arg(prism->noise.get(swapped)));
      rate.show();
      channel.show();
      signal.show();
      time.show();
      setUpdatesEnabled(true);

      return next_header (protocol::IEEE802_11, prism + 1);
    }

  } // End of namespace gui.

} // End of namespace wscout.
