/*
 * WScout - Lightweight PCAP visualizer.
 * Copyright (C) 2007, 2008  Universite Pierre et Marie Curie - Paris 6
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301  USA
 *
 * Author: Thomas Claveirole <thomas.claveirole@lip6.fr>
 */

#include <iostream>

#include <QtCore/QStringList>
#include <QtGui/QApplication>

#include "wscout_gui_main_window.hh"
#include "wscout_gui_pixmap.hh"
#include "wscout_gui_pcap_header.hh"
#include "wscout_gui_prism_header.hh"
#include "wscout_gui_ieee802_11_header.hh"
#include "wscout_gui_ieee802_11_beacon_header.hh"
#include "wscout_config.hh"

int
main(int argc, char* argv[])
{
  QApplication app (argc, argv);

  app.setApplicationName(WSCOUT_APPLICATION_NAME);
  app.setOrganizationDomain(WSCOUT_ORGANIZATION_DOMAIN);
  app.setOrganizationName(WSCOUT_ORGANIZATION_NAME);

  wscout::gui::pixmapInit();

  wscout::gui::PcapHeader::registerProtocol();
  wscout::gui::PrismHeader::registerProtocol();
  wscout::gui::IEEE80211Header::registerProtocol();
  wscout::gui::IEEE80211BeaconHeader::registerProtocol();

  wscout::gui::MainWindow* const	w = new wscout::gui::MainWindow;
  const QStringList			arguments = QApplication::arguments();

  w->setAttribute(Qt::WA_DeleteOnClose);
  w->show();
  for (int i = 1; i < arguments.size(); ++i)
    w->openTrace(arguments[i]);

  return app.exec();
}
