/*
 * WiPal - A library and a set of tools to manipulate wireless traces.
 * Copyright (C) 2007  Universite Pierre et Marie Curie - Paris 6
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301  USA
 *
 * Author: Thomas Claveirole <thomas.claveirole@lip6.fr>
 */
#ifndef PRISM_HEADER_HXX_
# define PRISM_HEADER_HXX_

# include "prism_header.hh"

# include <wipal/tool/endianness.hh>

namespace prism
{

  inline
  uint32_t
  item::get(bool swapped) const
  {
    return tool::extract_long_u(data, swapped);
  }

  inline
  item&
  item::set(uint32_t value, bool swapped)
  {
    status = 0;
    data = tool::extract_long_u(value, swapped);

    return *this;
  }

  inline
  bool
  eq_80211(const header* lhs, size_t lhs_caplen,
	   const header* rhs, size_t rhs_caplen)
  {
    const size_t caplen = std::min(lhs_caplen, rhs_caplen);

    if (caplen < sizeof (prism::header))
      return false;

    return 0 == memcmp(lhs + 1, rhs + 1, caplen - sizeof (prism::header));
  }

  inline
  bool
  eq_time_and_80211(const header* lhs, size_t lhs_caplen, bool lhs_swapped,
		    const header* rhs, size_t rhs_caplen, bool rhs_swapped,
		    unsigned	precision,
		    bool	check_hosttime)
  {
    const size_t caplen = std::min(lhs_caplen, rhs_caplen);

    if (caplen < sizeof (prism::header))
      return false;

    const unsigned dmac = std::abs(int (lhs->mactime.get(lhs_swapped) -
					rhs->mactime.get(rhs_swapped)));

    if (dmac > precision)
      return false;

    if (check_hosttime)
      {
	const unsigned dhost = std::abs(int (lhs->hosttime.get(lhs_swapped) -
					     rhs->hosttime.get(rhs_swapped)));

	if (dhost > precision / 10)
	  return false;
      }

    return 0 == memcmp(lhs + 1, rhs + 1, caplen - sizeof (prism::header));
  }

} // End of namespace prism.

#endif // ! PRISM_HEADER_HXX_
